-- Script to provide ArcSDE 8.3 compatibility with DB2 Spatial Extender V8.1
-- To be used with an ArcSDE 8.3 database which was created with DB2 V8.1.
-- This script to be run prior to 'sdesdetupdb2' command
-- See the related readme file for more information on using this script.
-- Last updated 06/11/03 - DWA

-- Modify the following connect statement to reference the appropriate database.
-- This should be run either under a dbadmin id or modify the connect
-- statement to provide a dbadmin userid and password.
CONNECT TO sde;

------------------------------------------------
-- Create V7 catalog table "DB2GSE  "."GSE_COORD_REF"
------------------------------------------------

 CREATE TABLE "DB2GSE  "."GSE_COORD_REF"  (
                  "SCID" INTEGER NOT NULL ,
                  "SC_NAME" VARCHAR(64) NOT NULL ,
                  "AUTH_NAME" VARCHAR(256) ,
                  "AUTH_SRID" INTEGER ,
                  "DESC" VARCHAR(256) ,
                  "SRTEXT" VARCHAR(2048) NOT NULL )
                 IN "USERSPACE1" ;

-- DDL Statements for primary key on Table "DB2GSE  "."GSE_COORD_REF"

ALTER TABLE "DB2GSE  "."GSE_COORD_REF"
        ADD CONSTRAINT "CO_REF_PK" PRIMARY KEY
                ("SCID");


-- DDL Statements for unique constraints on Table "DB2GSE  "."GSE_COORD_REF"

ALTER TABLE "DB2GSE  "."GSE_COORD_REF"
        ADD CONSTRAINT "CO_REF_UK" UNIQUE
                ("SC_NAME");

--------------------------------------------
-- Authorization Statements on Tables/Views
--------------------------------------------


 GRANT SELECT ON TABLE "DB2GSE  "."GSE_COORD_REF" TO  PUBLIC   ;

 GRANT DELETE ON TABLE "DB2GSE  "."GSE_COORD_REF" TO USER "DB2GSE  " ;

 GRANT INSERT ON TABLE "DB2GSE  "."GSE_COORD_REF" TO USER "DB2GSE  " ;

-- Create the 'UNKNOWN' coordinate system that was in V7
-- The csid will be different (not 0 as in V7)
insert into db2gse.gse_coordinate_systems
  (coordsys_name, definition)
  values('UNKNOWN', 'UNKNOWN')
;

insert into db2gse.gse_coordinate_systems_id
  values('UNKNOWN',
         (select max(coordsys_id)+1 from db2gse.gse_coordinate_systems_id))
  ;

update db2gse.gse_spatial_reference_systems
  set coordsys_name = 'UNKNOWN' where coordsys_name = 'UNSPECIFIED'
;


-- Copy all the values from the deprecated V7 catalog view defined in V8
-- to the mirrored V7 version of the coordinate system table
 INSERT INTO db2gse.gse_coord_ref select * from db2gse.coord_ref_sys;



-- Create the triggers to copy values from the V7 db2gse.gse_coord_ref
-- table (inserted by ArcSDE) into the V8 tables.
-- Normally this should be done by using the stored procedure
CREATE TRIGGER db2gse.sde_cs_ins1
AFTER INSERT ON db2gse.gse_coord_ref
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   insert into db2gse.gse_coordinate_systems
     select sc_name, srtext, auth_name, auth_srid, desc
       from db2gse.gse_coord_ref
         where sc_name = n.sc_name
;

CREATE TRIGGER db2gse.sde_cs_ins2
AFTER INSERT ON db2gse.gse_coord_ref
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   insert into db2gse.gse_coordinate_systems_id
     select sc_name, scid
       from db2gse.gse_coord_ref
         where sc_name = n.sc_name
;

-- Create the triggers to copy values from the V7 db2gse.gse_coord_ref
-- table (updated by ArcSDE) into the V8 tables.
-- Normally this should be done by using the stored procedure
CREATE TRIGGER db2gse.sde_cs_upd1
AFTER UPDATE ON db2gse.gse_coord_ref
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   update db2gse.gse_coordinate_systems
     set
       coordsys_name = n.sc_name,
       definition = n.srtext,
       organization = n.auth_name,
       organization_coordsys_id = n.auth_srid,
       description = n.desc
         where coordsys_name = n.sc_name
;

-- Create the triggers to delete values from the V7 db2gse.gse_coord_ref
-- table (deleted by ArcSDE) into the V8 tables.
-- Normally this should be done by using the stored procedure
CREATE TRIGGER db2gse.sde_cs_del1
AFTER DELETE ON db2gse.gse_coord_ref
REFERENCING OLD AS o FOR EACH ROW
MODE DB2SQL
   delete from db2gse.gse_coordinate_systems
         where coordsys_name = o.sc_name
;

------------------------------------------------
-- Define V7 catalog table "DB2GSE  "."GSE_SPATIAL_REF"
------------------------------------------------

 CREATE TABLE "DB2GSE  "."GSE_SPATIAL_REF"  (
                  "SRID" INTEGER NOT NULL ,
                  "SR_NAME" VARCHAR(64) NOT NULL ,
                  "SCID" INTEGER NOT NULL ,
                  "FALSEX" DOUBLE NOT NULL ,
                  "FALSEY" DOUBLE NOT NULL ,
                  "XYUNITS" DOUBLE NOT NULL ,
                  "FALSEZ" DOUBLE NOT NULL ,
                  "ZUNITS" DOUBLE NOT NULL ,
                  "FALSEM" DOUBLE NOT NULL ,
                  "MUNITS" DOUBLE NOT NULL )
                 IN "USERSPACE1" ;

-- DDL Statements for primary key on Table "DB2GSE  "."GSE_SPATIAL_REF"

ALTER TABLE "DB2GSE  "."GSE_SPATIAL_REF"
        ADD CONSTRAINT "SP_REF_PK" PRIMARY KEY
                ("SRID");


-- DDL Statements for unique constraints on Table "DB2GSE  "."GSE_SPATIAL_REF"

ALTER TABLE "DB2GSE  "."GSE_SPATIAL_REF"
        ADD CONSTRAINT "SP_REF_UK" UNIQUE
                ("SR_NAME");

-- DDL Statements for foreign keys on Table "DB2GSE  "."GSE_SPATIAL_REF"

ALTER TABLE "DB2GSE  "."GSE_SPATIAL_REF"
        ADD CONSTRAINT "SP_REF_FK" FOREIGN KEY
                ("SCID")
        REFERENCES "DB2GSE  "."GSE_COORD_REF"
                ("SCID")
        ON DELETE RESTRICT
        ON UPDATE RESTRICT;

--------------------------------------------
-- Authorization Statements on Tables/Views
--------------------------------------------


 GRANT SELECT ON TABLE "DB2GSE  "."GSE_SPATIAL_REF" TO  PUBLIC   ;

 GRANT DELETE ON TABLE "DB2GSE  "."GSE_SPATIAL_REF" TO USER "DB2GSE  " ;

 GRANT INSERT ON TABLE "DB2GSE  "."GSE_SPATIAL_REF" TO USER "DB2GSE  " ;

 GRANT UPDATE ON TABLE "DB2GSE  "."GSE_SPATIAL_REF" TO USER "DB2GSE  " ;

-- Copy all the values from the deprecated V7 catalog view defined in V8
-- to the mirrored V7 version of the spatial reference table
 INSERT INTO db2gse.gse_spatial_ref
   select srid, sr_name, csid, falsex, falsey, xyunits, falsez, zunits, falsem, munits
   from db2gse.spatial_ref_sys;


--
-- Create the trigger to populate the mirrored V7 catalog table when
-- the V8 catalog table is inserted into.
CREATE TRIGGER db2gse.sde_spat_ref_ins
AFTER INSERT ON db2gse.gse_spatial_reference_systems
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   insert into db2gse.gse_spatial_ref
     select srid, sr_name, csid, falsex, falsey, xyunits, falsez, zunits, falsem, munits
       from db2gse.spatial_ref_sys
         where srid = n.srs_id
;
--
-- Create the trigger to update the mirrored V7 catalog table when
-- the V8 catalog table is updated.
-- It isn't obvious that this is ever a good idea other than to change the
-- description which doesn't exist in the V7 table.
CREATE TRIGGER db2gse.sde_spat_ref_upd
AFTER UPDATE ON db2gse.gse_spatial_reference_systems
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   update db2gse.gse_spatial_ref
     set
       falsex = n.x_offset,
       falsey = n.y_offset,
       xyunits = n.x_scale,
       falsez = n.z_offset,
       zunits = n.z_scale,
       falsem = n.m_offset,
       munits = m_scale
         where sr_name = n.srs_name;
;

--
-- Create the trigger to delete from the mirrored V7 catalog table when
-- the V8 catalog table is deleted from.
CREATE TRIGGER db2gse.sde_spat_ref_del
AFTER DELETE ON db2gse.gse_spatial_reference_systems
REFERENCING OLD AS o FOR EACH ROW
MODE DB2SQL
   delete from db2gse.gse_spatial_ref
         where srid = o.srs_id
;




------------------------------------------------
-- DDL Statements for table "DB2GSE  "."GSE_LAYER"
------------------------------------------------

 CREATE TABLE "DB2GSE  "."GSE_LAYER"  (
                  "LAYER_TYPE" INTEGER NOT NULL ,
                  "LAYER_CATALOG" VARCHAR(30) ,
                  "LAYER_SCHEMA" VARCHAR(30) NOT NULL ,
                  "LAYER_TABLE" VARCHAR(128) NOT NULL ,
                  "LAYER_COLUMN" VARCHAR(128) NOT NULL ,
                  "GEO_SCHEMA" VARCHAR(30) NOT NULL ,
                  "GEO_TABLE" VARCHAR(128) NOT NULL ,
                  "GEO_COLUMN" VARCHAR(128) NOT NULL )
                 IN "USERSPACE1" ;

-- DDL Statements for primary key on Table "DB2GSE  "."GSE_LAYER"

ALTER TABLE "DB2GSE  "."GSE_LAYER"
        ADD CONSTRAINT "LAYER_PK" PRIMARY KEY
                ("LAYER_SCHEMA",
                 "LAYER_TABLE",
                 "LAYER_COLUMN");

--------------------------------------------
-- Authorization Statements on Tables/Views
--------------------------------------------


 GRANT SELECT ON TABLE "DB2GSE  "."GSE_LAYER" TO  PUBLIC   ;

 GRANT DELETE ON TABLE "DB2GSE  "."GSE_LAYER" TO USER "DB2GSE  " ;

 GRANT INSERT ON TABLE "DB2GSE  "."GSE_LAYER" TO USER "DB2GSE  " ;

 GRANT UPDATE ON TABLE "DB2GSE  "."GSE_LAYER" TO USER "DB2GSE  " ;

------------------------------------------------
-- DDL Statements for view  "DB2GSE  "."GSE_LAYER_GEOM"
------------------------------------------------

 CREATE VIEW  "DB2GSE  "."GSE_LAYER_GEOM"  (
                  "GEO_SCHEMA"                      ,
                  "GEO_TABLE"                       ,
                  "GEO_COLUMN"                       ,
                  "GEOMETRY_TYPE"                  ,
                  "SRID"                  ,
                  "STORAGE_TYPE"         ,
                  "CONSTRAINT_NAME"                      ,
                  "NUM_ATTR"                  ,
                  "SRC_ATTR1"              ,
                  "SRC_ATTR2"              ,
                  "SRC_ATTR3"              ,
                  "SRC_ATTR4"              ,
                  "SRC_ATTR5"              ,
                  "SRC_ATTR6"              ,
                  "SRC_ATTR7"              ,
                  "SRC_ATTR8"              ,
                  "SRC_ATTR9"              ,
                  "SRC_ATTR10"              ,
                  "GCID"         ,
                  "PRECISION_LEVEL"         ,
                  "VENDOR_SPECIFIC"              ,
                  "AUTOGC_MODE"         ,
                  "INS_TRIGGER_NAME"             ,
                  "UPD_TRIGGER_NAME"             )
                 AS SELECT  layer_schema, layer_table, layer_column,
                            geometry_type, srid, storage_type,
                            'DUMMY_CONSTRAINT',
                            0,
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS INTEGER),
                            CAST(NULL AS INTEGER),
                            CAST(NULL AS VARCHAR(256)),
                            CAST(NULL AS INTEGER),
                            CAST(NULL AS VARCHAR(18)),
                            CAST(NULL AS VARCHAR(18))
                FROM db2gse.geometry_columns;

-- The following are required for a non-DBADM ArcSDE user
grant delete on db2gse.gse_layer to public;
grant delete on db2gse.gse_layer_geom to public;
grant update,insert on db2gse.gse_coord_ref to public;
grant update,insert on db2gse.gse_coordinate_systems to public;
grant update,insert on db2gse.gse_coordinate_systems_id to public;
--grant update,insert on db2gse.gse_spatial_ref to public;
GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError(INTEGER) TO PUBLIC;

GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError
  (INTEGER, varchar(128))
  TO PUBLIC;

GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError
  (INTEGER, varchar(128), varchar(128))
  TO PUBLIC;

GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError
  (INTEGER, varchar(128), varchar(128), varchar(128))
  TO PUBLIC;

-- The following are required for a non-DBADM ArcSDE user to import
-- data which will construct a geometry using the mutators
GRANT EXECUTE ON FUNCTION db2gse.ST_LINESTRING() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_MULTILINESTRING() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_MULTIPOINT() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_MULTIPOLYGON() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_POINT() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_POLYGON() TO PUBLIC;
GRANT EXECUTE ON METHOD ANNO_TEXT() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ANNO_TEXT(VARCHAR(256)) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD AREA() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD AREA(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD EXT() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD EXT(DB2GSE.SE_EXTENSION) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD GEOMETRY_TYPE() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD GEOMETRY_TYPE(INTEGER) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD GEOMETRY_TYPE(SMALLINT) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD LENGTH() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD LENGTH(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD NUMPOINTS() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD NUMPOINTS(INTEGER) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD POINTS() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD POINTS(BLOB) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD SRID() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD SRID(INTEGER) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;

COMMIT WORK;

CONNECT RESET;

TERMINATE;
